288	   0	manuscript/Appendix A -- Your NLP Tools.adoc
204	   0	manuscript/Appendix B -- Playful Python and Regular Expressions.adoc
257    0	manuscript/Appendix C -- Vectors and Matrices (Basic Linear Algebra).adoc
401    0	manuscript/Appendix D -- Machine Learning.adoc
207    0	manuscript/Appendix E -- AWS GPU.adoc
251	    0	manuscript/Appendix F -- Locality Sensitive Hashing.adoc
-	   -	manuscript/BIO_Lane, Hapke, Howard.doc
39	   0	manuscript/Chapter 00 -- About this Book.adoc
46	   0	manuscript/Chapter 00 -- Acknowledgments.adoc
20	   0	manuscript/Chapter 00 -- Foreword by Arwen Griffioen.adoc
159	   0	manuscript/Chapter 00 -- Preface.adoc
20	   0	manuscript/Chapter 01 - 04 -- Part 01 -- Wordy Machines (Vector Models of Natural Language).adoc
706	   0	manuscript/Chapter 01 -- Packets of Thought (NLP Overview).adoc
1870	0	manuscript/Chapter 02 -- Build Your Vocabulary (Word Tokenization).adoc
1046	0	manuscript/Chapter 03 -- Math with Words (TF-IDF Vectors).adoc
2274	0	manuscript/Chapter 04 -- Finding Meaning in Word Counts (Semantic Analysis).adoc
22	    0	manuscript/Chapter 05 - 10 -- Part 02 -- Deeper Learning (Neural Networks).adoc
718	    0	manuscript/Chapter 05 -- Baby Steps with Neural Networks (Perceptrons and Backpropagation).adoc
1334	0	manuscript/Chapter 06 -- Reasoning with Word Vectors (Word2vec).adoc
794	   0	manuscript/Chapter 07 -- Getting Words in Order with Convolutional Neural Networks (CNNs).adoc
762	   0	manuscript/Chapter 08 -- Loopy (Recurrent) Neural Networks (RNNs).adoc
1242	0	manuscript/Chapter 09 -- Improving Retention with Long Short-Term Memory Networks (LSTMs).adoc
790	   0	manuscript/Chapter 10 -- Sequence to Sequence Models and Attention (Generative Models).adoc
11	   0	manuscript/Chapter 11 - 15 -- Part 03 -- Getting Real (Real World NLP Challenges).adoc
1005	0	manuscript/Chapter 11 -- Information Extraction (Named Entity Extraction and Question Answering).adoc
444	   0	manuscript/Chapter 12 -- Stackable Deep Learning (Attention, Networks, Transformers, BERT, GPT).adoc
48	   0	manuscript/Chapter 13 -- Getting Creative (Summarization, Paraphrasing, Generation).adoc
844	   0	manuscript/Chapter 14 -- Scaling Up (Optimization, Parallelization and Batch Processing).adoc
1297	0	manuscript/Chapter 15 -- Getting Chatty (Dialog Engines).adoc
